pub enum Error {
Io(Error),
Parse {
source: Box<SourceFile>,
diagnostics: Vec<Diagnostic>,
},
Runtime {
source: Option<Box<SourceFile>>,
error: Box<RuntimeError>,
},
MissingFunction(String),
Conversion(String),
StaleHostHandle {
id: u64,
},
HostTypeMismatch {
expected: &'static str,
},
}Expand description
Error returned by the Kinetik embedding API.
Variants
Io(Error)
A script file could not be read.
Parse
Source text could not be parsed.
Fields

source: Box<SourceFile>Source file associated with the diagnostics.

diagnostics: Vec<Diagnostic>Diagnostics emitted by lexing or parsing.
Runtime
Runtime evaluation failed.
Fields

source: Option<Box<SourceFile>>Source file associated with the runtime span.

error: Box<RuntimeError>Runtime error emitted by the VM.
MissingFunction(String)
A requested function is not defined.
Conversion(String)
A value could not be converted to a requested Rust type.
StaleHostHandle
A host handle no longer refers to a live host object.
HostTypeMismatch
A host handle was accessed as the wrong Rust type.